@@ -30,35 +30,43 @@ NEMIVER_BEGIN_NAMESPACE (nemiver)
 
 /// \brief A container of the textual command sent to the debugger
 class Command {
+    UString m_cookie ;
     UString m_name ;
-    UString m_value ;
+    UString m_value;
     UString m_tag0 ;
     UString m_tag1 ;
-    UString m_cookie ;
+    int m_tag2;
     IDebugger::VariableSafePtr m_var ;
 
 public:
 
-    Command ()  {clear ();}
+    Command ():
+      m_tag2 (0)
+    {
+        clear ();
+    }
 
     /// \param a_value a textual command to send to the debugger.
     Command (const UString &a_value) :
-        m_value (a_value)
+        m_value (a_value),
+        m_tag2 (0)
     {
     }
 
     Command (const UString &a_name, const UString &a_value) :
         m_name (a_name),
-        m_value (a_value)
+        m_value (a_value),
+        m_tag2 (0)
     {
     }
 
     Command (const UString &a_name,
              const UString &a_value,
              const UString &a_cookie) :
+        m_cookie (a_cookie),
         m_name (a_name),
         m_value (a_value),
-        m_cookie (a_cookie)
+        m_tag2 (0)
     {
     }
 
@@ -81,7 +89,10 @@ public:
     const UString& tag1 () const {return m_tag1;}
     void tag1 (const UString &a_in) {m_tag1 = a_in;}
 
-    void variable (const IDebugger::VariableSafePtr &a_in) {m_var = a_in;}
+    int tag2 () const {return m_tag2;}
+    void tag2 (int a_in) {m_tag2 = a_in;}
+
+    void variable (const IDebugger::VariableSafePtr a_in) {m_var = a_in;}
     IDebugger::VariableSafePtr variable () const {return m_var;}
 
     /// @}
@@ -161,27 +172,12 @@ public:
     class OutOfBandRecord {
     public:
 
-        enum StopReason {
-            UNDEFINED=0,
-            BREAKPOINT_HIT,
-            WATCHPOINT_TRIGGER,
-            READ_WATCHPOINT_TRIGGER,
-            ACCESS_WATCHPOINT_TRIGGER,
-            FUNCTION_FINISHED,
-            LOCATION_REACHED,
-            WATCHPOINT_SCOPE,
-            END_STEPPING_RANGE,
-            EXITED_SIGNALLED,
-            EXITED,
-            EXITED_NORMALLY,
-            SIGNAL_RECEIVED
-        };//end enum StopReason
 
     private:
         bool m_has_stream_record;
         StreamRecord m_stream_record ;
         bool m_is_stopped ;
-        StopReason m_stop_reason ;
+        IDebugger::StopReason m_stop_reason ;
         bool m_has_frame ;
         IDebugger::Frame m_frame ;
         long m_breakpoint_number ;
@@ -193,48 +189,48 @@ public:
 
         OutOfBandRecord () {clear ();}
 
-        UString stop_reason_to_string (StopReason a_reason) const
+        UString stop_reason_to_string (IDebugger::StopReason a_reason) const
         {
             UString result ("undefined") ;
 
             switch (a_reason) {
-                case UNDEFINED:
+                case IDebugger::UNDEFINED_REASON:
                     return "undefined" ;
                     break ;
-                case BREAKPOINT_HIT:
+                case IDebugger::BREAKPOINT_HIT:
                     return "breakpoint-hit" ;
                     break ;
-                case WATCHPOINT_TRIGGER:
+                case IDebugger::WATCHPOINT_TRIGGER:
                     return "watchpoint-trigger" ;
                     break ;
-                case READ_WATCHPOINT_TRIGGER:
+                case IDebugger::READ_WATCHPOINT_TRIGGER:
                     return "read-watchpoint-trigger" ;
                     break ;
-                case ACCESS_WATCHPOINT_TRIGGER:
+                case IDebugger::ACCESS_WATCHPOINT_TRIGGER:
                     return "access-watchpoint-trigger" ;
                     break ;
-                case FUNCTION_FINISHED:
+                case IDebugger::FUNCTION_FINISHED:
                     return "function-finished" ;
                     break ;
-                case LOCATION_REACHED:
+                case IDebugger::LOCATION_REACHED:
                     return "location-reached" ;
                     break ;
-                case WATCHPOINT_SCOPE:
+                case IDebugger::WATCHPOINT_SCOPE:
                     return "watchpoint-scope" ;
                     break ;
-                case END_STEPPING_RANGE:
+                case IDebugger::END_STEPPING_RANGE:
                     return "end-stepping-range" ;
                     break ;
-                case EXITED_SIGNALLED:
+                case IDebugger::EXITED_SIGNALLED:
                     return "exited-signaled" ;
                     break ;
-                case EXITED:
+                case IDebugger::EXITED:
                     return "exited" ;
                     break ;
-                case EXITED_NORMALLY:
+                case IDebugger::EXITED_NORMALLY:
                     return "exited-normally" ;
                     break ;
-                case SIGNAL_RECEIVED:
+                case IDebugger::SIGNAL_RECEIVED:
                     return "signal-received" ;
                     break ;
             }
@@ -255,12 +251,12 @@ public:
         bool is_stopped () const {return m_is_stopped;}
         void is_stopped (bool a_in) {m_is_stopped = a_in;}
 
-        StopReason stop_reason () const {return m_stop_reason ;}
+        IDebugger::StopReason stop_reason () const {return m_stop_reason ;}
         UString stop_reason_as_str () const
         {
             return stop_reason_to_string (m_stop_reason) ;
         }
-        void stop_reason (StopReason a_in) {m_stop_reason = a_in;}
+        void stop_reason (IDebugger::StopReason a_in) {m_stop_reason = a_in;}
 
         bool has_frame () const {return m_has_frame;}
         void has_frame (bool a_in) {m_has_frame = a_in;}
@@ -290,7 +286,7 @@ public:
             m_has_stream_record = false ;
             m_stream_record.clear () ;
             m_is_stopped = false ;
-            m_stop_reason = UNDEFINED ;
+            m_stop_reason = IDebugger::UNDEFINED_REASON ;
             m_has_frame = false ;
             m_frame.clear () ;
             m_breakpoint_number = 0 ;
@@ -359,6 +355,24 @@ public:
         IDebugger::Frame m_current_frame_in_core_stack_trace ;
         bool m_has_current_frame_in_core_stack_trace ;
 
+        // register names
+        std::map<IDebugger::register_id_t, UString> m_register_names ;
+        bool m_has_register_names ;
+
+        // register values
+        std::map<IDebugger::register_id_t, UString> m_register_values ;
+        bool m_has_register_values ;
+
+        // changed registers
+        std::list<IDebugger::register_id_t> m_changed_registers ;
+        bool m_has_changed_registers ;
+
+        // memory values
+        std::vector<uint8_t> m_memory_values;
+        size_t m_memory_address;
+        bool m_has_memory_values;
+
+
     public:
         ResultRecord () {clear () ;}
 
@@ -387,6 +401,49 @@ public:
             m_call_stack = a_in;
             has_call_stack (true) ;
         }
+        bool has_register_names () const { return m_has_register_names; }
+        void has_register_names (bool a_flag) { m_has_register_names = a_flag; }
+        const std::map<IDebugger::register_id_t, UString>& register_names () const { return m_register_names; }
+        void register_names (const std::map<IDebugger::register_id_t, UString>& a_names)
+        {
+            m_register_names = a_names;
+            has_register_names (true);
+        }
+
+        bool has_changed_registers () const { return m_has_changed_registers; }
+        void has_changed_registers (bool a_flag) { m_has_changed_registers = a_flag; }
+        const std::list<IDebugger::register_id_t>& changed_registers () const
+        {
+            return m_changed_registers;
+        }
+        void changed_registers (const std::list<IDebugger::register_id_t>& a_regs)
+        {
+            m_changed_registers = a_regs;
+            has_changed_registers (true);
+        }
+
+        bool has_register_values () const { return m_has_register_values; }
+        void has_register_values (bool a_flag) { m_has_register_values = a_flag; }
+        const std::map<IDebugger::register_id_t, UString>& register_values () const
+        {
+            return m_register_values;
+        }
+        void register_values (const std::map<IDebugger::register_id_t, UString>& a_regs)
+        {
+            m_register_values = a_regs;
+            has_register_values (true);
+        }
+
+        bool has_memory_values () const { return m_has_memory_values; }
+        void has_memory_values (bool a_flag) { m_has_memory_values = a_flag; }
+        const std::vector<uint8_t>& memory_values () const { return m_memory_values; }
+        size_t memory_address () const { return m_memory_address; }
+        void memory_values (size_t a_address, const std::vector<uint8_t>& a_values)
+        {
+            m_memory_address = a_address;
+            m_memory_values = a_values;
+            has_memory_values (true);
+        }
 
         const map<int, list<IDebugger::VariableSafePtr> >&
                                                     frames_parameters () const
@@ -507,6 +564,15 @@ public:
             m_file_list.clear () ;
             m_has_file_list = false ;
             m_has_current_frame_in_core_stack_trace = false ;
+            m_has_changed_registers = false;
+            m_changed_registers.clear ();
+            m_has_register_values = false;
+            m_register_values.clear ();
+            m_has_register_names = false;
+            m_register_names.clear ();
+            m_memory_values.clear ();
+            m_memory_address = 0;
+            m_has_memory_values = false;
         }
     };//end class ResultRecord
 
