@@ -264,6 +264,10 @@ public:
 
     IDebugger::State get_state () const ;
 
+    int get_current_frame_level () const;
+
+    void set_current_frame_level (int);
+
     void step_in (const UString &a_cookie) ;
 
     void step_out (const UString &a_cookie) ;
@@ -319,7 +323,9 @@ public:
     void select_frame (int a_frame_id,
                        const UString &a_cookie) ;
 
-    void list_frames (const UString &a_cookie) ;
+    void list_frames (int a_low_frame,
+                      int a_high_frame,
+                      const UString &a_cookie);
 
     void list_frames_arguments (int a_low_frame,
                                 int a_high_frame,
