@@ -743,6 +743,8 @@ public:
 
     virtual IDebugger::State get_state () const = 0;
 
+    virtual int get_current_frame_level () const = 0;
+
     virtual bool stop_target () = 0;
 
     virtual void exit_engine () = 0;
@@ -799,7 +801,9 @@ public:
     virtual void select_frame (int a_frame_id,
                                const UString &a_cookie="") = 0;
 
-    virtual void list_frames (const UString &a_cookie="") = 0;
+    virtual void list_frames (int a_low_frame=-1,
+                              int a_high_frame=-1,
+                              const UString &a_cookie="") = 0;
 
     virtual void list_frames_arguments (int a_low_frame=-1,
                                         int a_high_frame=-1,
